@@ -1,6 +1,7 @@
 .onLoad <- function(libname, pkgname) {
 	.jinit(parameters="-Xrs")
 	.jpackage(pkgname)
+	.jpackage("JGR")
 	
 	classes <- system.file("jri", package = "rJava", lib.loc = NULL)
 	if (nchar(classes)) {
@@ -11,19 +12,6 @@
 		}		
 	}
 	
-	rJavaVersion <- utils::sessionInfo()$otherPkgs$rJava$Version
-	# If we have a rJava version > 0.9-3 load JRIEngine.jar and REngine.jar
-    if (!is.null(rJavaVersion) && rJavaVersion > "0.9-3") {
-		classes <- system.file("JRI", package = "CommonJavaJars", lib.loc = NULL)
-		if (nzchar(classes)) {
-			.jaddClassPath(classes)
-			jars <- grep(".*\\.jar", list.files(classes, full.names = TRUE), TRUE, value = TRUE)
-			if (length(jars)) { 
-				.jaddClassPath(jars)
-			}		
-		}
-	}
-	
 	classes <- system.file("java", package = "JavaGD", lib.loc = NULL)
 	if (nchar(classes)) {
 		.jaddClassPath(classes)
@@ -35,10 +23,11 @@
 	
 	jars <- c("afcommons", "commons-collections", "commons-lang", 
 			"commons-logging", "commons-validator", "forms", 
-			"iText", "jhlir.jar", "jxlayer", 
-			"log4j", "swing-worker", "poi")
+			"iText", "jhlir.jar", "jxlayer", "log4j", "swing-worker")
 	
 	loadJars(jars)
+  # As soon as we require CommonJavaJars >= 1.0-5 we can drop this following line:
+  try(loadJars("jgoodies-common"), silent=TRUE)
 	
 	## we supply our own JavaGD class
 	Sys.setenv("JAVAGD_CLASS_NAME"="org/mutoss/gui/JavaGD")
